@@ -10,7 +10,10 @@ def print_horizontal_line():
 def log_response(resp):
     status_code = resp.status_code
     print("[DEBUG] resp status: {0}".format(status_code))
-    print("[DEBUG] resp body: {0}".format(resp.json()))
+    try:
+        print("[DEBUG] resp body: {0}".format(resp.json()))
+    except ValueError:
+        print("[DEBUG] resp body: {0}".format(resp.text))
     return resp
 
 
